import { auctionUtils } from './auction-utiils';
import { PUBLIC_URLS } from '../config/public-endpoints';

/**
 * auction-overview component event state
 */
let auctionOverviewMouseDown = false;
let auctionOverviewStartX;
let auctionOverviewScrollLeft;

/**
 * init will fetch from the public caronsale auction-overview endpoint 20 auctions
 * and render a vertical scrollable list of auctions
 *
 * @type {{ init: auctionOverview.init }}
 */
export const auctionOverview = (() => ({
  init: function () {
    $.get(PUBLIC_URLS.auctions, (auctions) => {
      auctions.forEach(function (auction) {
        const $auctionContainer = $('.auction-container');

        const vehicleImageUrl = auction.associatedVehicle.vehicleImages[0].url;
        const vehicleLabel = auction.associatedVehicle.make + ' ' + auction.associatedVehicle.model;

        const formattedMileage = auctionUtils.formatMileageInKm(auction.associatedVehicle.mileageInKm);
        const vehicleCategory = auctionUtils.getVehicleCategory(auction.associatedVehicle.category);
        const vehicleFuelType = auctionUtils.getVehicleFuelType(auction.associatedVehicle.fuelType);
        const formattedEndingTime = auctionUtils.getEndingTime(auction.endingTime);

        const vehicleSubLabel = `${auction.associatedVehicle.ez} | ${formattedMileage} | ${vehicleCategory} | ${vehicleFuelType}`;

        $auctionContainer.append(
          `<a href="https://app.caronsale.de/register/salesman" target="__blank" style="text-decoration: none; color: #2f343e;">` +
            `<div class="auction-card">` +
            `<img src="${auctionUtils.getImageThumbnail(vehicleImageUrl, 268, 170)}" alt="">` +
            `<div>` +
            `<div class="text-block-13">${vehicleLabel}</div>` +
            `<div class="text-block-14">${vehicleSubLabel}</div>` +
            `</div>` +
            `<div class="div-block-23"></div>` +
            `<div class="text-block-15">${formattedEndingTime}</div>` +
            `</div>` +
            `</a>`
        );
      });
    });
  },
  initScrollListeners: function () {
    const $auctionOverview = document.querySelector('.auction-container');

    $auctionOverview.addEventListener('mousedown', function (e) {
      auctionOverviewMouseDown = true;
      $auctionOverview.classList.add('active');
      auctionOverviewStartX = e.pageX - $auctionOverview.offsetLeft;
      auctionOverviewScrollLeft = $auctionOverview.scrollLeft;
    });

    $auctionOverview.addEventListener('mouseleave', function (e) {
      auctionOverviewMouseDown = false;
      $auctionOverview.classList.remove('active');
    });

    $auctionOverview.addEventListener('mouseup', function (e) {
      auctionOverviewMouseDown = false;
      $auctionOverview.classList.remove('active');
    });

    $auctionOverview.addEventListener('mousemove', function (e) {
      if (!auctionOverviewMouseDown) return;

      e.preventDefault();

      const x = e.pageX - $auctionOverview.offsetLeft;
      const walk = x - auctionOverviewStartX;

      $auctionOverview.scrollLeft = auctionOverviewScrollLeft - walk;
    });
  }
}))();
