import { accordion } from './shared/accordion';
import { cookiePolicy } from './shared/cookie-policy';
import { navigationBar } from './shared/navigation-bar';
import { footer } from './shared/footer';
import { mobileStoreBadges } from './shared/mobile-store-badges';
import { languageSwitch } from './shared/language-switch';
import { auctionOverview } from './auctions/public-auction-overview';
import { innovativeFunctions } from './buyer/innovative-functions';
import { sellerClickEvents } from './seller/seller-events';
import { buyerEvents } from './buyer/buyer-events';
import { agbs } from './shared/agb';
import { sharedClickEvents } from './shared/shared-click-events';
import { campaignEvents } from './campain/campaign-events';
import { anangEvents } from './anang/anang-events';
import { socialMediaBadges } from './shared/social-media-badges';
import { botStar } from './chatbot/botstar';

/**
 * main entrypoint which initializes all other scripts
 */
document.addEventListener('DOMContentLoaded', (event) => {
  // shared, should be initialized on every page
  botStar.init();
  accordion.init({ speed: 300, oneOpen: true });
  cookiePolicy.init();
  navigationBar.init();
  footer.init();
  socialMediaBadges.init();
  mobileStoreBadges.init();
  languageSwitch.init();

  // initializing buyer, seller, shared click events
  sellerClickEvents.init();
  buyerEvents.init();
  sharedClickEvents.init();

  // initializing campaign
  campaignEvents.init();

  // initializing anang
  anangEvents.init();

  // initializing auction overview only for root-page
  if (location.pathname === '/') {
    auctionOverview.init();
    auctionOverview.initScrollListeners();
    innovativeFunctions.init();
  }

  if (location.pathname === '/agb') {
    agbs.init();
  }
});
